package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.42.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.42.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````L"4```````!``````````%BQ````
M`````````$``.``-`$``'@`=``8````$````0`````````!``````````$``
M````````V`(```````#8`@````````@``````````P````0````8`P``````
M`!@#````````&`,````````<`````````!P``````````0`````````!````
M!````````````````````````````````````/`<````````\!P`````````
M$`````````$````%`````"``````````(``````````@````````K3X`````
M``"M/@`````````0`````````0````0`````8`````````!@`````````&``
M``````"(1P```````(A'`````````!`````````!````!@```*"K````````
MH+L```````"@NP```````(@$````````^`0`````````$`````````(````&
M````T*L```````#0NP```````-"[````````(`(````````@`@````````@`
M````````!`````0````X`P```````#@#````````.`,```````!`````````
M`$``````````"``````````$````!````'@#````````>`,```````!X`P``
M`````$0`````````1``````````$`````````%/E=&0$````.`,````````X
M`P```````#@#````````0`````````!```````````@`````````4.5T9`0`
M``"PH````````+"@````````L*````````#\`````````/P`````````!```
M``````!1Y71D!@``````````````````````````````````````````````
M```````````0`````````%+E=&0$````H*L```````"@NP```````*"[````
M````8`0```````!@!`````````$`````````+VQI8C8T+VQD+6QI;G5X+7@X
M-BTV-"YS;RXR```````$````,`````4```!'3E4``H``P`0````!````````
M``$``<`$````"0`````````"``'`!`````$`````````!````!`````!````
M1TY5```````$`````P`````````$````%`````,```!'3E4`AQ=!<#CSBA2>
MCSVM\*JK<;]XA&4`````0P```%X``````````````%4`````````)P````4`
M````````3``````````]````4@```#4````E````5````%$````O````.```
M````````````7```````````````)````"8```!*````'````!X````6````
M30```$L`````````````````````````/@```#<```!9`````````$D````N
M`````````#H`````````'0```%H````8````(@```%<`````````10``````
M```"`````````%@````V````!````#P`````````1````%,```!0````,@``
M``P````_````.0```"L```!!````````````````````````````````````
M``````````````````````@```!"``````````````````````````<```!'
M```````````````-````$0```%L````4````````````````````````````
M```;````3@````D````:````$@``````````````1@``````````````````
M``8````3`````P`````````J`````````$@````M````#@```",````7````
M*0```"`````+````(0```!`````P````+````!\```!``````````#,```!/
M`````````"@```!=```````````````T``````````````!6````````````
M```5`````````#$````[````#P```$,``````````````!D````*````````
M`````````````````````````````````````````````0`````````1````
M/P````0````(````(!P0``5`!(8H`@`$@(8`A(*)`"))(`0(F(`10;H``@H`
M````/P```$(```!%````1@```$X```!/````40````````!4````50```%8`
M``!8````6@```%P``````````````&[%WQ_.WD<M:W^:?"[%F[;49-1\(?_D
M#MEQ6!SB1\8!L@&+;ZQ+X\!"^M>'PN4_++KCDGSZH6Q@F4_#FVL)0]9FK\QF
MQ;F<0#CRBQQ"1=7LB0=PTS-BV^T5C"7,##J7"Z?=HVM^J9R;T67.;>"G`@IK
M&IY0"HH05Z/@^TD```````````````````````````````"F`@``$@``````
M```````````````````-`@``$@````````````````````````"-`@``$@``
M``````````````````````"T````$@````````````````````````#H`0``
M$@````````````````````````!)`@``$@`````````````````````````!
M````(`````````````````````````"X`0``$@``````````````````````
M``!G````$@````````````````````````#%`0``$@``````````````````
M``````#4````$@````````````````````````"&`@``$@``````````````
M``````````#8`@``$@````````````````````````#]`0``$@``````````
M```````````````H`0``$@`````````````````````````X`0``$@``````
M``````````````````"F````$@````````````````````````!Q`0``$@``
M``````````````````````!J`0``$@````````````````````````!]`P``
M$@`````````````````````````0````(`````````````````````````"^
M`@``$@````````````````````````"K`@``$@``````````````````````
M``#<````$@`````````````````````````L````(```````````````````
M``````#Z````$@`````````````````````````(`0``$@``````````````
M``````````"I`0``$@````````````````````````"P`@``$@``````````
M``````````````"3````%@`````````````````````````^`0``$@``````
M``````````````````!<`@``$@````````````````````````!9`0``$@``
M``````````````````````#)`@``$@````````````````````````":`0``
M$@````````````````````````#V`0``$@````````````````````````"[
M````$@````````````````````````"*````$@``````````````````````
M``!^`0``$@````````````````````````"8`@``$@``````````````````
M``````#7`0``$@````````````````````````"%`0``$@``````````````
M```````````N`@``$@````````````````````````!Y````$@``````````
M``````````````"3`0``$@````````````````````````",`0``$@``````
M``````````````````#Y````$@````````````````````````#*`0``$@``
M```````````````````````9`@``$@````````````````````````!Z`@``
M$@````````````````````````"]`0``$@`````````````````````````O
M`0``$@`````````````````````````:`0``$@``````````````````````
M```!`0``$@````````````````````````#Q````$@``````````````````
M``````!.`0``$@````````````````````````#C````$@``````````````
M```````````Z`@``$@````````````````````````!&````$@``````````
M``````````````#A`@``$@`````````````````````````0`0``$@``````
M``````````````````#1`0``$@````````````````````````"&`P``$@`0
M`#!9````````Q@````````#;`P``$@`0`!!0````````"0<```````!3````
M$@`0`*`C````````"P(```````#]`@``$@`0`(!$````````!0`````````;
M`P``$@`0`"!7````````"`(````````!!```$@`0`)!$````````&@(`````
M``#!`P``$``;`$#````````````````````.`P``$@`0`+!&````````'P``
M```````Q`P``$@`0`(!,````````80````````"2`P``$0`2``!@````````
M!`````````"N`P``$@`0`%!:````````N@$```````"Y`P``$@`0`'!#````
M````)0````````#6`P``$``;`)C```````````````````#O`P``$@`0`"!/
M````````Y0`````````8!```$@`0`/!,````````M`````````"A`P``$``:
M``#```````````````````!5`P``$@`0`-!&````````00$```````#*````
M$0`;`$#`````````"`````````"B`0``$0`;`&#`````````"`````````#H
M`P``$``:`"C````````````````````.!```$0`:`"#`````````"```````
M``"G`P``$@`0`+`E````````)@````````#-`P``$@`0``!:````````10``
M``````"C`P``(``:``#```````````````````#,````(0`;`$#`````````
M"`````````!K`P``$@`0``!/````````'0````````!8````(@``````````
M```````````````_`P``$@`0`*!#````````W0````````!A`P``$@`0`!!<
M````````8P(```````!M`@``$0`;`'#``````````0`````````@!```$@`0
M`"!(````````6P0`````````7U]G;6]N7W-T87)T7U\`7TE435]D97)E9VES
M=&5R5$U#;&]N951A8FQE`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`7U]L
M:6)C7W-T87)T7VUA:6X`7U]C>&%?9FEN86QI>F4`7U]R96=I<W1E<E]A=&9O
M<FL`7U]S=&%C:U]C:&M?9F%I;`!R96%D;&EN:P!03%]C=7)R96YT7V-O;G1E
M>'0`4&5R;%]S=E]S971P=@!M96UC:'(`4&5R;%]S=E]S971P=FX`7U]E;G9I
M<F]N`'-T<FYC;7``<W1R;&5N`%]?;65M;6]V95]C:&L`<F5A;&QO8P!L<W1A
M=#8T`&%C8V5S<P!O<&5N9&ER`')E861D:7(V-`!?7W-P<FEN=&9?8VAK`'5N
M;&EN:P!C;&]S961I<@!R;61I<@!B;V]T7T1Y;F%,;V%D97(`4&5R;%]N97=8
M4P!097)L7VYE=UA37V9L86=S`&=E='!I9`!?7VUE;6-P>5]C:&L`<W1R8VAR
M`'-T<F1U<`!S=')T;VL`<W1R8VUP`'-T<G)C:'(`<W1D97)R`%]?=F9P<FEN
M=&9?8VAK`&5X:70`;'-E96LV-`!R96%D`&=E='5I9`!M:V1I<@!?7V5R<FYO
M7VQO8V%T:6]N`%]?9G!R:6YT9E]C:&L`;W!E;C8T`%!E<FQ?9W9?9F5T8VAP
M=@!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E
M=`!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]U;FQO8VL`4&5R;%]A=&9O
M<FM?;&]C:P!03%]D;U]U;F1U;7``4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?
M<&%R<V4`<&5R;%]D97-T<G5C=`!P97)L7V9R964`4&5R;%]S>7-?=&5R;0!P
M97)L7V%L;&]C`'!E<FQ?8V]N<W1R=6-T`'!E<FQ?<G5N`&UE;6-P>0!L:6)P
M97)L+G-O`&QI8F,N<V\N-@!P87)?8W5R<F5N=%]E>&5C`'!A<E]B87-E;F%M
M90!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`<VAA7V9I;F%L`&=E=%]U<V5R
M;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%])3U]S=&1I;E]U<V5D
M`%]?9&%T85]S=&%R=`!S:&%?=7!D871E`'AS7VEN:70`7U]B<W-?<W1A<G0`
M<VAA7VEN:70`7V5N9`!P87)?;6MT;7!D:7(`7V5D871A`'!A<E]S971U<%]L
M:6)P871H`'!A<E]F:6YD<')O9P!M>5]P87)?<&P`<&%R7V1I90!P87)?:6YI
M=%]E;G8`1TQ)0D-?,BXQ-`!'3$E"0U\R+C,T`$=,24)#7S(N-`!'3$E"0U\R
M+C,S`$=,24)#7S(N,RXR`$=,24)#7S(N,RXT`$=,24)#7S(N,BXU`"]U<W(O
M;&EB+W!E<FPU+S4N-#(N,"]X.#9?-C0M;&EN=7@M=&AR96%D+6UU;'1I+T-/
M4D4``````0`!``$``@`#``$``0`"``0``@`"``(``0`!``(``@`!``,``@`"
M``$``0`"``(``0`%``(``P`!``$``0`!``$``0`"``(``0`"``(``0`"``(`
M`0`&``(``@`%``(``0`!``(``@`#``(``@`!``,``0`'``@``@`"``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`"``(``0`!``$``0`!``(`
M`0`"``$``0`!``$````!``<`\P(``!``````````E)&6!@``"``M!```$```
M`+21E@8```<`.`0``!`````4:6D-```&`$,$```0````LY&6!@``!0!-!```
M$````'(9:0D```0`6`0``!````!T&6D)```#`&0$```0````=1II"0```@!P
M!````````*"[````````"`````````"0)@```````*B[````````"```````
M``!0)@```````+"[````````"`````````!.80```````+B[````````"```
M``````#I8````````,"[````````"``````````&80```````,B[````````
M"`````````!?80````````C`````````"``````````(P````````"#`````
M````"`````````#X8@```````+B_````````!@````8``````````````,"_
M````````!@````<``````````````,B_````````!@```!4`````````````
M`-"_````````!@```!D``````````````-B_````````!@```%D`````````
M`````."_````````$@```!X``````````````.B_````````!@```!\`````
M`````````/"_````````!@```"```````````````/B_````````!@```#L`
M`````````````$#`````````!0```%```````````````&#`````````!0``
M`%$``````````````'#`````````!0```%P```````````````B^````````
M!P````$``````````````!"^````````!P````(``````````````!B^````
M````!P````,``````````````""^````````!P````0``````````````"B^
M````````!P````4``````````````#"^````````!P````@`````````````
M`#B^````````!P````D``````````````$"^````````!P````H`````````
M`````$B^````````!P````L``````````````%"^````````!P````P`````
M`````````%B^````````!P````T``````````````&"^````````!P````X`
M`````````````&B^````````!P````\``````````````'"^````````!P``
M`!```````````````'B^````````!P```!$``````````````("^````````
M!P```!(``````````````(B^````````!P```!,``````````````)"^````
M````!P```!0``````````````)B^````````!P```!8``````````````*"^
M````````!P```!<``````````````*B^````````!P```!@`````````````
M`+"^````````!P```!H``````````````+B^````````!P```!L`````````
M`````,"^````````!P```!P``````````````,B^````````!P```!T`````
M`````````-"^````````!P```"$``````````````-B^````````!P```"(`
M`````````````."^````````!P```",``````````````.B^````````!P``
M`"0``````````````/"^````````!P```"4``````````````/B^````````
M!P```"8```````````````"_````````!P```"<```````````````B_````
M````!P```"@``````````````!"_````````!P```"D``````````````!B_
M````````!P```"H``````````````""_````````!P```"L`````````````
M`"B_````````!P```"P``````````````#"_````````!P```"T`````````
M`````#B_````````!P```"X``````````````$"_````````!P```"\`````
M`````````$B_````````!P```#```````````````%"_````````!P```#$`
M`````````````%B_````````!P```#(``````````````&"_````````!P``
M`#,``````````````&B_````````!P```#0``````````````'"_````````
M!P```#4``````````````'B_````````!P```#8``````````````("_````
M````!P```#<``````````````(B_````````!P```#@``````````````)"_
M````````!P```#D``````````````)B_````````!P```#H`````````````
M`*"_````````!P```#P``````````````*B_````````!P```#T`````````
M`````+"_````````!P```#X`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``#S#Q[Z2(/L"$B+!;&?``!(A<!T`O_02(/$",,``````/\UTIT``/\EU)T`
M``\?0`#_)=*=``!H`````.G@_____R7*G0``:`$```#IT/____\EPIT``&@"
M````Z<#_____);J=``!H`P```.FP_____R6RG0``:`0```#IH/____\EJIT`
M`&@%````Z9#_____):*=``!H!@```.F`_____R6:G0``:`<```#I</____\E
MDIT``&@(````Z6#_____)8J=``!H"0```.E0_____R6"G0``:`H```#I0/__
M__\E>IT``&@+````Z3#_____)7*=``!H#````.D@_____R5JG0``:`T```#I
M$/____\E8IT``&@.````Z0#_____)5J=``!H#P```.GP_O___R52G0``:!``
M``#IX/[___\E2IT``&@1````Z=#^____)4*=``!H$@```.G`_O___R4ZG0``
M:!,```#IL/[___\E,IT``&@4````Z:#^____)2J=``!H%0```.F0_O___R4B
MG0``:!8```#I@/[___\E&IT``&@7````Z7#^____)1*=``!H&````.E@_O__
M_R4*G0``:!D```#I4/[___\E`IT``&@:````Z4#^____)?J<``!H&P```.DP
M_O___R7RG```:!P```#I(/[___\EZIP``&@=````Z1#^____)>*<``!H'@``
M`.D`_O___R7:G```:!\```#I\/W___\ETIP``&@@````Z>#]____)<J<``!H
M(0```.G0_?___R7"G```:"(```#IP/W___\ENIP``&@C````Z;#]____);*<
M``!H)````.F@_?___R6JG```:"4```#ID/W___\EHIP``&@F````Z8#]____
M)9J<``!H)P```.EP_?___R62G```:"@```#I8/W___\EBIP``&@I````Z5#]
M____)8*<``!H*@```.E`_?___R5ZG```:"L```#I,/W___\E<IP``&@L````
MZ2#]____)6J<``!H+0```.D0_?___R5BG```:"X```#I`/W___\E6IP``&@O
M````Z?#\____)5*<``!H,````.G@_/___R5*G```:#$```#IT/S___\E0IP`
M`&@R````Z<#\____)3J<``!H,P```.FP_/___R4RG```:#0```#IH/S___\E
M*IP``&@U````Z9#\____)4*<``!FD```````````55-(@^PXB7PD'$B-?"0<
M2(ET)!!(C70D$$B)5"0(9$B+%"4H````2(E4)"A(C50D".AZ____2(LUVYL`
M`$B+/0R<``!(B?+HHCH``(`]?9P````/A!P!``!(BP7@FP``9$B+`("(.@0`
M``.+1"0<C7@$C5@#2&/_2,'G`^BO_O__2(M,)!!$BT0D'$B)QTB)!5.<``!(
MBP%(B0=(C06E/0``2(E'"$B+!=.;``!(B4<02(T%DCT``$B)1QA!@_@!#XXL
M`0``2(/!"$&#P`.X!````&9F+@\?A```````9I!(BS%(8]"#P`%(@\$(2(DT
MUT0YP'7J2)A(B?E%,<")VDC'!,<`````2(L]R9L``$B--6H>``#HE?O__X7`
M#X2"````2(L]KIL``.AA_?__2(UT)"1(C3W(.P``B<7H_A@``$B%P'1O2(L]
MBIL``.@]^___Z+C\__](BT0D*&1(*P0E*`````^%F@```$B#Q#B)Z%M=P^@V
M_/__2(D%5YL``$B%P'1V2(G'Z*+\__](BP6KF@``9$B+$,:"M@@```#IN_[_
M_TB+/2R;``#H?_O__^EM____2(L](YL``$B%_W0*Z,DS``#I>____TB-/>4Z
M``!(C70D).AC&```2(D%_)H``$B)QTB%P`^$5____^O0N`0```#I^O[__[\!
M````Z-KZ___HQ?S__P\?1```\P\>^C'M28G17DB)XDB#Y/!05$4QP#')2(T]
MT?W___\5(YH``/1F+@\?A```````2(T]09H``$B-!3J:``!(.?AT%4B+!<Z9
M``!(A<!T"?_@#Q^``````,,/'X``````2(T]$9H``$B--0J:``!(*?Y(B?!(
MP>X_2,'X`T@!QDC1_G042(L%E9D``$B%P'0(_^!F#Q]$``###Q^``````/,/
M'OJ`/1::````=2M52(,]<ID```!(B>5T#$B+/9:9``#H&?W__^AD____Q@7N
MF0```5W##Q\`PP\?@`````#S#Q[ZZ7?___\/'X``````05=,C4]X059!54%4
M55-(@>R8`@``9$B+-"4H````2(FT)(@"``!(C7<X28G@#Q\`BP9(BPY(@\8(
M28/`$`_(B<!(B<I)B4#P2(G(2,'J($C!Z"A(P>DX)0#_``!("<A(B=%(P>((
M2,'A&('B``#_`(G)2`G(2`G028E`^$DY\76ON_____]F#V]$)!!(C40D:&8/
M;UPD(&9(#V[K9@]O5"0P2(V4)&@"``!F#VSM9I#S#V\(9@]OXF8/;U#82(/`
M$&8/[T"(9@_ORF8/[\%F#V_(9@]S\`%F#W/1'V8/Z\%F#]O%#RE`"&8/;\-F
M#V_<2#G"=;M,BP],BU\02(MW($B+7QA,B<A,B<I(BV\(2(M,)`A(P>H;2,'@
M!4@)T`,$)$B-C`N9>8):C90PF7F"6DR)V$@QV$@AZ$@QV(TT`DB)ZDB)Z$C!
MZ`)(P>(>28GR2`G"3(G82<'J&T&)T$PQP$PAR$PQV$@!R$B)\4C!X05,"=%,
MBU0D$$2-)`A,B<A,B<E(P>D"2,'@'D^-E!.9>8):38GE2`G(2<'M&T@QPHG!
M2"'R3#'"3`'238GB2<'B!4T)ZDR+;"0800'22(GR2,'N`DC!XAY%B=)/C80H
MF7F"6D@)\DV)U4@QT(G63"'@2<'M&T@QR$P!P$V)T$G!X`5-">A,BVPD($$!
MP$R)X$G![`)(P>`>18G`2HV,*9EY@EI,">!-B<5(,<))P>T;08G$3"'22#'R
M2`'*3(G!2,'A!4P)Z4R+;"0H`=%,B=))P>H"2,'B'HG)2HVT+IEY@EI,"=))
MB<U(,=!)P>T;08G23"'`3#'@2`'P2(G.2,'F!4P)[DR+;"0P`<9,B<!)P>@"
M2,'@'HGV3XVD+)EY@EI,"<!)B?5(,<))P>T;08G`2"'*3#'23`'B28GT2<'D
M!4T)[$R+;"0X00'42(G*2,'I`DC!XAY%B>1/C90JF7F"6D@)RDV)Y4@QT$G!
M[1N)T4@A\$PQP$P!T$V)XDG!X@5-">I,BVPD0$$!PDB)\$C![@)(P>`>18G2
M3XV$*)EY@EI("?!-B=5(,<))P>T;B<9,(>)(,<I,`<)-B=!)P>`%30GH3(ML
M)$A!`=!,B>))P>P"2,'B'D6)P$J-C"F9>8):3`GB38G%2#'02<'M&T&)U$PA
MT$@Q\$@!R$R)P4C!X05,">E,BVPD4`'!3(G02<'J`DC!X!Z)R4J-M"Z9>8):
M3`G028G-2#'"2<'M&T&)PDPAPDPQXD@!\DB)SDC!Y@5,">Y,BVPD6`'63(G"
M2<'H`DC!XAZ)]D^-I"R9>8):3`G"28GU2#'02<'M&T&)T$@AR$PQT$P!X$F)
M]$G!Y`5-">Q,BVPD8$$!Q$B)R$C!X!Y(P>D"18GD3XV4*IEY@EI("<A-B>5(
M,<))P>T;B<%((?),,<),`=)-B>))P>(%30GJ3(ML)&A!`=)(B?)(P>X"2,'B
M'D6)TD^-A"B9>8):2`GR38G52#'02<'M&XG63"'@2#'(3`'`38G02<'@!4T)
MZ$R+;"1P00'`3(G@2<'L`DC!X!Y%B<!*C8PIF7F"6DP)X$V)Q4@QPDG![1M!
MB<1,(=)(,?)(`<I,B<%(P>$%3`GI3(ML)'@!T4R)TDC!XAY)P>H"B<E*C;0N
MF7F"6DP)TDF)S4@QT$G![1M!B=),(<!,,>!(`?!(B<Y(P>8%3`GN3(NL)(``
M```!QDR)P$G!Z`)(P>`>B?9/C:0LF7F"6DP)P$F)]4@QPDG![1M!B<!((<I,
M,=),`>))B?1)P>0%30GL1HTL(DB)RDC!Z0),BZ0DB````$C!XAY("<I/C90B
MF7F"6DV)[$@QT$G![!N)T4@A\$PQP$P!T$V)ZDG!X@5-">),BZ0DD````$$!
MPDB)\$C!X!Y(P>X"18G23XV$()EY@EI("?!-B=1(,<))P>P;B<9,(>I(,<I,
M`<)-B=!)P>`%30G@18G`3`'"38GH2<'M`DG!X!Y!B=1-">A,BZPDF````$PQ
MP$PAT$J-C"F9>8):38GE2#'P2<'M&T@!R$R)X4C!X05,">F)R4@!R$R)T4G!
MZ@)(P>$>08G%3`G138G"18G`23'*1#'23(N4)*````!*C;06H>O9;DV)ZD@!
MUDR)ZDG!ZAM(P>(%3`G2B=)(`=9,B>)(P>(>2<'L`D&)\DP#A"2H````3`GB
M28G,B<E(`XPDL````$DQU$0QX$V-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")
MP$D!Q$R)Z$G![0)(P>`>18G@3`GH28G5B=)(`Y0DN````$DQQ40Q[DR-K#&A
MZ]EN3(G!3(G&2,'N&TC!X05("?&)R4D!S4R)T4G!Z@)(P>$>1(GN3`G128G"
MB<!),<I%,>).C:02H>O9;DB)\DF)\DG!ZAM(P>(%3`G2B=))`=1,B<))P>@"
M2,'B'D6)XDP)PDF)R$@#A"3`````B<E),=!(`XPDR````$4QZ$Z-K`"AZ]EN
M3(G038G02<'H&TC!X`5,"<")P$D!Q4B)\$C![@)(P>`>18GH2`GP2(G6B=)(
M`Y0DT````$@QQD0QYDR-I#&AZ]EN3(G!3(G&2,'N&TC!X05("?&)R4D!S$R)
MT4G!Z@)(P>$>1(GF3`G128G"B<!(`X0DV````$DQRD4QZDZ-K!*AZ]EN2(GR
M28GR2<'J&TC!X@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!(
M`XPDX````$4QX$Z-I`"AZ]EN3(G038G02<'H&TC!X`5,"<")P$D!Q$B)\$C!
M[@)(P>`>18G@2`GP2(G6B=)(`Y0DZ````$@QQD0Q[DR-K#&AZ]EN3(G!3(G&
M2,'N&TC!X05("?&)R4D!S4R)T4G!Z@)(P>$>1(GN3`G128G"B<!(`X0D\```
M`$DQRD4QXDZ-I!*AZ]EN2(GR28GR2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(
MP>(>18GB3`G"28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$C!X`5)P>@;2`.,
M)/@```!,"<")P$D!Q4B)\$C![@)(P>`>18GH2`GP2(G6B=)(`Y0D``$``$@Q
MQD0QYDR-I#&AZ]EN3(G!3(G&2,'N&TC!X05("?&)R4D!S$R)T4G!Z@)(P>$>
M1(GF3`G128G"B<!(`X0D"`$``$DQRD4QZDZ-K!*AZ]EN2(GR28GR2<'J&TC!
MX@5,"=*)TDD!U4R)PDG!Z`)(P>(>18GJ3`G"28G(B<E),=!%,>!.C:0`H>O9
M;DR)T$V)T$G!Z!M(P>`%3`G`2`.,)!`!``")P$D!Q$B)\$C![@)(P>`>18G@
M2`GP2(G6B=)(`Y0D&`$``$@QQD0Q[DR-K#&AZ]EN3(G!3(G&2,'N&TC!X05(
M"?&)R4D!S4R)T4G!Z@)(P>$>1(GN3`G128G"B<!(`X0D(`$``$DQRD4QXDZ-
MI!*AZ]EN2(GR28GR2<'J&TC!X@5,"=*)TDD!U$R)PDG!Z`)(P>(>18GB3`G"
M28G(B<E),=!%,>A.C:P`H>O9;DR)T$V)T$G!Z!M(P>`%3`G`B<!)`<5(B?!(
MP>`>2,'N`D6)Z$@#C"0H`0``2`GP2(G6B=)(`Y0D,`$``$@QQD0QYDV)Q$B-
MC#&AZ]EN3(G&2<'L&TC!Y@5,">9-B=1)P>H"2<'D'HGV30G428G"2`'QB<!-
M,>*)SD@#A"0X`0``13'J28GU3HV4$J'KV6Y(B?))P>T;2,'B!4P)ZD$!TDR)
MPDG!Z`)(P>(>18G23`G"38G@18GD23'028G608G51#'!38G02(V,"*'KV6Y,
MB=!)P>@;2,'@!4P)P$2-!`%(B?%(P>X"N-R\&X](P>$>2`GQ20G.B<Y((?)-
M(=9)"=9(BY0D0`$``$@!PDP!XDV)Q$P!\DV)QDG!Y`5)P>X;30GT00'43(G2
M2<'J`DC!XAY%B>1,"=)("=%)B=9!B=))(?9,(<%,"?%,B[0D2`$``$D!QDT!
M]4V)YDP!Z4V)Y4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!
MB<A)"<Y-(>9,(<),"?),B[0D4`$``$D!QDP!]DV)[D@!\DR)[DG![AM(P>8%
M3`GV`=9,B>))P>P"2,'B'HGV3`GB2`G128G608G432'&3"'I3`GQ3(NT)%@!
M``!)`<9-`?))B?9,`=%)B?))P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>
M18G23`GI08G-20G.22'V3"'J3`GR3(NT)&`!``!)`<9-`?!-B=9,`<)-B=!)
MP>`%2<'N&TT)\$$!T$B)\DC![@)(P>(>18G`2`GR2`G128G6B=9-(>Y,(=%,
M"?%,B[0D:`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G1
M2<'J`DC!X1Y%B>1,"=%!B<I)"<Y-(<9,(=),"?),B[0D<`$``$D!QDT!]4V)
MYDP!ZDV)Y4G![AM)P>4%30GU00'53(G"2,'B'DG!Z`)%B>U,"<)("=%)B=9!
MB=!-(=9,(>%,"?%,B[0D>`$``$D!QDP!]DV)[D@!\4R)[DG![AM(P>8%3`GV
M28G6`<Y,B>%)P>P"2,'A'HGV3`GA08G,20G.32'N3"'B3`GR3(NT)(`!``!)
M`<9-`?))B?9,`=))B?))P>X;2<'B!4T)\D$!TDR)ZDG![0)(P>(>18G23`GJ
M2`G128G608G52"'Q32'F3`GQ3(NT)(@!``!)`<9-`?!-B=9,`<%-B=!)P>X;
M2<'@!4T)\$F)UD$!R$B)\4C![@)(P>$>18G`2`GQB<Y)"<Y-(=9((?),"?),
MB[0DD`$``$D!QDT!]$V)QDP!XDV)Q$G![AM)P>0%30GT00'43(G22<'J`DC!
MXAY%B>1,"=)("=%)B=9!B=))(?9,(<%,"?%,B[0DF`$``$D!QDT!]4V)YDP!
MZ4V)Y4G![AM)P>4%30GU28G600'-3(G!2<'H`DC!X1Y%B>U,"<%!B<A)"<Y-
M(>9,(<),"?),B[0DH`$``$D!QDP!]DV)[D@!\DR)[DG![AM(P>8%3`GV`=9,
MB>))P>P"2,'B'HGV3`GB2`G128G608G432'&3"'I3`GQ3(NT)*@!``!)`<9-
M`?))B?9,`=%)B?))P>X;2<'B!4T)\DF)UD$!RDR)Z4G![0)(P>$>18G23`GI
M08G-20G.22'V3"'J3`GR3(NT)+`!``!)`<9-`?!-B=9,`<)-B=!)P>X;2<'@
M!4T)\$$!T$B)\DC![@)(P>(>18G`2`GR2`G128G6B=9-(>Y,(=%,"?%,B[0D
MN`$``$D!QDT!]$V)QDP!X4V)Q$G![AM)P>0%30GT28G600',3(G12<'J`DC!
MX1Y%B>1,"=%)"<Y!B<I-(<9,(=),"?),B[0DP`$``$D!QDT!]4V)YDP!ZDV)
MY4G![AM)P>4%30GU00'53(G"2<'H`DC!XAY%B>U,"<)("=%)B=!!B==-(=!,
M(>%,"<%,BX0DR`$``$D!P$P!QDV)Z$@!\4R)[DG!Z!M(P>8%3`G&1(T$,4R)
MYDG![`)(B=%(P>8>3`GF08GT2`GQ3"'I3"'B2`G*2(N,)-`!``!(`<%,`=%-
MB<)(`X0DV`$``$@!RDR)P4G!ZAM(P>$%3`G1B<E(`<I,B>E)P>T"2,'A'D&)
MTDP)Z4@)SDF)S4&)SDPAQDTAY4D)]4J--#A,B=!,B[PD^`$``$P![DV)U4C!
MX`5)P>T;3`GHB<!(`<9,B<!)P>@"2,'@'D&)]4D)P+C6P6+*3#'!,=%(BY0D
MX`$``$@!PDP!XDV)[$@!RDR)Z4G![!M(P>$%3`GA38G4B<E)P>0>2`'*2<'J
M`DD!QTT)XDV)Q(G118G`33'41#'F3(ND).@!``!)`<1-`?1)B<Y,`>9)B<Q)
MP>X;2<'D!4T)]$V)[DG![0))P>8>18GD30GU3(NT)/`!``!,`>9!B?1)`<9-
M`?!-B=9-,>Y$,?)-B>9)`=!,B>))P>X;2,'B!4P)\HG220'02(G*2,'I`DC!
MXAY%B<9("<I$B=%-B>I),=),`?E,B[PD``(``$0QUDV)\D@!SDR)\4C!X05)
MP>H;20''3`G1B<E(`<Y,B>%)P>P"2,'A'D&)\DD)S$2)Z4F)U8G233'E3`'Y
M3(N\)!`"``!%,>A-B=5)`<A,B=%)P>T;20''2,'A!4P)Z8G)20'(3(GQ2<'N
M`DC!X1Y%B<5,"?%,B[0D"`(``$D!QDP!\DV)YDDQSD0Q]DV)[D@!UDR)ZDG!
M[AM(P>(%3`GRB=)(`=9,B=))P>H"2,'B'D&)]DD)TD2)XDF)S(G)3`'Z33'4
M3(N\)"`"``!%,>!-B?1)`=!,B?))P>P;20''2,'B!4P)XHG220'03(GJ2<'M
M`DC!XAY%B<1,">I,BZPD&`(``$D!Q4P!Z4V)U4DQU40Q[DV)Y4@!SDR)X4G!
M[1M(P>$%3`GIB<E(`<Y,B?%)P>X"2,'A'D&)]4D)SD2)T4F)THG233'R3`'Y
M3(N\)#`"``!%,=!-B>I)`<A,B>E)P>H;2,'A!4P)T8G)20'(3(GA2,'A'DG!
M[`)%B<))`<=,">%,BZ0D*`(``$D!Q$P!XDV)]$DQS$0QYDV)U$@!UDR)TDG!
M[!M(P>(%3`GBB=)(`=9,B>I)P>T"2,'B'D&)]$D)U42)\DF)SHG)33'N3`'Z
M3(N\)$`"``!%,?!-B>9)`=!,B>))P>X;2,'B!4P)\HG220'03(G22<'J`DC!
MXAY%B<9,"=),BY0D.`(``$D!PDP!T4V)ZDDQTD0QUDV)\D@!SDR)\4C!X05)
MP>H;20''3`G1B<E(`<Y,B>%)P>P"2,'A'D&)\DD)S$2)Z4F)U8G233'E3`'Y
M3(N\)&`"``!%,>A-B=5)`<A,B=%)P>T;2,'A!4P)Z8G)20'(3(GQ2<'N`DC!
MX1Y%B<5,"?%,B[0D2`(``$D!QDP!\DV)YD6)Y$DQSD0Q]DV)[D@!UDR)ZDG!
M[AM(P>(%3`GRB=)(`=9,B=))P>H"2,'B'D&)]DD)TDB+E"10`@``2`'"20'4
M2(G*B<E,,=))`<=$,<)-B?!)`=1,B?))P>@;2,'B!4P)PHG220'43(GJ2<'M
M`DC!XAY%B>!,">I,BZPD6`(``$D!Q4P!Z4V)U4DQU40Q[DV)Q4@!SDR)P4G!
M[1M(P>$%3`GIB<E(`<Y,B?%)P>X"2,'A'D&)]4D)SD2)T4F)THG233'R3`'Y
M3(N\)'`"``!%,>)-B>Q,`=%-B>I)P>P;2<'B!4T)XDV)Q$6)TDG!Y!Y,`=%)
MP>@"20''30G@3(ND)&@"``!!B<I)`<1(`X0D>`(``$P!XDV)]$P!R$TQQ$0Q
MYDV)U$@!UDR)TDG![!M(P>(%3`GB38GL2<'M`DG!Y!Z)TDT)Y46)]$V)QD@!
MUDTQ[HGR30'\18G`1#'Q28G63`'`38GH3`'A28G42<'N&TG!Y`5-"?1$`>%-
MB=1)P>H"2<'D'HG)30GB33'01#'&28G(2`'P2(G.2,'F!4G!Z!L!Z4$!VDP)
MQD0#;R!(B4\(`?!,B5<82(D'2(G02,'J`DC!X!Y,B6\@2`G01`'82(E'$$B+
MA"2(`@``9$@K!"4H````=1)(@<28`@``6UU!7$%=05Y!7\/H=N7__V8/'T0`
M`$%455-(@>P`$```2(,,)`!(@^P@NO\/``!D3(LD)2@```!,B:0D&!```$F)
M]$B)_4B-="002(T]R"(``.C/Y/__A<!^%$ACR(/H`4ACT(!\%!``=4N%P'4U
M2(L%@((``$R)XDB)[F1(BSCHH>/__TB+A"08$```9$@K!"4H````=5E(@<0@
M$```6UU!7,-(8\AF9BX/'X0```````\?0`!(B<J^+P```$B-?"002(E,)`CH
MJ>+__TB%P'2=2(L%'8(``$B+3"0(2(U4)!!(B>YD2(LXZ"?D___KE.B0Y/__
M05=!5D%505154TB#[`A,BRU+@@``387M#X2C````#[8'A,!T!#P]=6=%,>1)
MBUT`2(7;=$%)B?=)B?Y-8^1,B>UF9BX/'X0```````\?0`!,B>),B?9(B=_H
M<N+__X7`=0="@#PC/71'2(M="$B#Q0A(A=MUVDB#Q`A(B=A;74%<05U!7D%?
MPP\?A```````28G\00^V1"0!28/$`83`=`0\/77N02G\ZX)F#Q]$``!,*>U*
MC5PC`4C!_0-!B2_KM3';Z[%F9BX/'X0``````$%6,<!!54%455-(@^P@@#X]
M9$B+'"4H````2(E<)!A(B?L/E,!(C2P&2(GOZ(_B__](C70D%$F)Q$B)W^CO
M_O__2(7`#X0>`0``2(G'28G%Z&OB__],.>`/@^H```!,8VPD%$G!Y0,/M@.$
MP`^$S@$``#P]#X3&`0``2(G89F8N#Q^$```````/'X0```````^V4`%(@\`!
MA-)T!8#Z/77O2"G82)A,BS7C@```2HU\(`+H6>'__TT![DF)!DB%P'1?2(L%
MQX```$J+%"@/M@.(`CP]=#"$P'0L2(U#`>L59F8N#Q^$```````/'T0``(#Y
M/701#[8(2(/"`4B#P`&("H3)=>K&`CTQP`\?1```#[9,!0"(3`(!2(/``83)
M=>](BT0D&&1(*P0E*`````^%'P$``$B#Q"!;74%<05U!7L-F#Q]$```QP&8/
M'T0```^V5`4`08A4!0!(@\`!A-)U[NN]#Q]``$R+#2&```!)@SD`#X3.````
M3(G(13'V9F8N#Q^$``````!F#Q]$``!(@\`(1(GR08/&`4B#.`!U[XU*`TAC
MR4C!X0.+!2^```"%P'5C2(G/3(E,)`C'!1F````!````2(D,).A`X/__2(G'
M2(7`#X1%____36/N2(L,)$B+="0(2<'E`TR)ZNB<XO__2(D%E7\``$B)QT6-
M1@%-8\!*QP3'`````.E5_O__9@\?1```3(G/2(G.Z$WB__](B05F?P``2(G'
M2(7`#X3K_O__36/N2<'E`^N_D#'`Z5_^__^Y$````$4Q]NE7____Z&?A__\/
M'X``````4TB![*````!D2(L<)2@```!(B9PDF````$B)^TB)YNALX?__A<!U
M.(M4)!B!X@#P``"!^@!```!T"('Z`*```'4@O@(```!(B=_HL>'__X7`#Y3`
M#[;`ZPD/'X``````,<!(BY0DF````&1(*Q0E*````'4)2('$H````%O#Z-W@
M__]F9BX/'X0``````&:005954TB![+````!D2(L$)2@```!(B80DJ````#'`
M2(7_=`A(B?N`/P!U)4B+A"2H````9$@K!"4H````#X4M`0``2('$L````%M=
M05[#9I#HF]___TB)Q4B%P'3.2(GOZ&OA__](A<`/A,(```!,C4@3@'@3+G4(
M08!Y`0!TWI"`>!,N#X2^````2(G?3(D,).@ZW___3(L,)$F)QDR)STR)3"0(
MZ";?__]!C50&`DACTDB)UTB)%"3H8M[__TR+3"0(2(L4)$F)V$F)QDB)Q[X"
M````,<!(C0V5'0``Z'W@__],B?=(C70D$.CPWO__3(GW@_C_=!"+1"0H)0#P
M```]`$```'1@Z$/>__],B??HJ][__TB)[^BSX/__2(7`#X5(____9BX/'X0`
M`````$B)[^@8X/__2(G?Z"#>___IYO[__P\?`$&`>0$N#X4W____08!Y`@`/
MA/_^___I)____P\?1```Z)/^___KGNA<W___9F8N#Q^$``````"04TB+';A\
M``!(C0U!70``2(TUXQP``$B+%:M\``!D2(L[Z.K?__]D2(L[13')6TR-!6\>
M``!(C17$$P``3(G!2(TUSQP``.E5WO__#Q]$``!(BP5I?```2(L5:GP``$B-
M#>M<``!(C36-'```9$B+..F;W___9F8N#Q^$``````!54TB![``0``!(@PPD
M`$B![``0``!(@PPD`$B#[#AD2(L$)2@```!(B80D*"```#'`2(UL)!#H5=W_
M_[H!$```O@(```!,C0TC'```08G`2(T-5!P``#'`2(V\)"`0``#H^][__TB-
MO"0@$```N@`0``!(B>[H]MW__S'_A<!X.(U(`4B)PTACR4B)STB)3"0(Z(K<
M__](B<=(A<!T&DACVTB+3"0(2(GN2(G:Z,_<___&!!@`2(G'2(N$)"@@``!D
M2"L$)2@```!U#4B!Q#@@``!(B?A;7</H\]W__P\?`.D;____9F8N#Q^$````
M``!!5T%6055!5%532('L`!```$B##"0`2('LN````&1(BQPE*````$B)G"2H
M$```2(GS28G\2(UT)`Q(C3V(&P``Z`OY__^^+P```$R)YTB)Q>@[W?__2(7`
M=#Y,B>9(C3UM&P``Z+?Y__],B>!(BY0DJ!```&1(*Q0E*`````^%D@$``$B!
MQ+@0``!;74%<05U!7D%?PP\?`$B)W^@@W?__2(TU-QL``$B)Q^A1W?__2(G#
M2(7`=*-,C:PDH````$R-="00@#L`#X27````#Q\`2(7M=`](B=Y(B>_H$-W_
M_X7`=%U(B=_H]-O__TB-5`/_28G'2#G3<B/K,69F+@\?A```````9BX/'X0`
M`````,8"`$B#Z@%(.=-T!8`Z+W3O2(G?Z+?;__])B<=,B>?HK-O__TF-1`<"
M2#W_#P``=D](C366&@``,?_HL=S__TB)PTB%P`^$__[__X`[``^%;/___TB%
M[70&@'T`+G010;\!````2(T=2AH``.NN9I"`?0$`=+OKYP\?A```````2(/L
M"$B-#4D;``!)B=@QP$%4N@`0``"^`@```$R)[TR-#2H:``#HM=S__TR)]DR)
M[^@JV___6EF%P`^%<?___XM$)"@E`/```#T`@```#X5=____O@$```!,B>_H
MC]S__X7`#X5(____3(GN2(T]SAD``.@8^/__3(GOZ+#;___I5_[__^C&V___
M9@\?1```4[XO````2(G[Z"+;__](C7@!2(7`2`]$^UOI@=O__Y!(@>P`$```
M2(,,)`!(@^PH9$B+!"4H````2(F$)!@0```QP$B%_P^$W````(`_``^$TP``
M`$B)?"0(Z&':__])B<!(C4`!2#T`$```#X?F````2(U4)!!(BW0D"$F)T8/X
M"'(.B<%(B=?!Z0/S2*5)B?DQR:@$=`J+#D&)";D$````J`)T#0^W/`YF08D\
M"4B#P0*H`70(#[8$#D&(!`E*C40"_T@YPG(3ZQ8/'T0``,8``$B#Z`%(.=!T
M!8`X+W3O2(G7OB\```!(B50D".@]VO__2(M4)`A(A<!T*T@YPG).2(G7Z);:
M__](BY0D&!```&1(*Q0E*````'4_2('$*!```,,/'P!(BX0D&!```&1(*P0E
M*````'4A2(T]9!@``$B!Q"@0``#I4MK__V:0Q@``ZZT/'P`QP.NNZ%_:__]F
M9BX/'X0```````\?0`!32(/L$&1(BP0E*````$B)1"0(,<!F9BX/'X0`````
M`$B-="0$2(T])A@``.B/]?__2(7`=$)(8U0D!$B+!=YW``!(C0302(M0"$B)
M$$B%TG3.9F8N#Q^$```````/'P!(BU`02(/`"$B)$$B%TG7PZZYF#Q]$``!(
MC70D!$B-/=<7``#H-_7__TB%P'0Z2&-4)`1(BP6&=P``2(T$T$B+4`A(B1!(
MA=)TSF8/'T0``$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-="0$2(T]CQ<`
M`.CG]/__2(7`=#I(8U0D!$B+!39W``!(C0302(M0"$B)$$B%TG3.9@\?1```
M2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(UT)`1(C3U(%P``Z)?T__](A<!T
M.DAC5"0$2(L%YG8``$B-!-!(BU`(2(D02(72=,YF#Q]$``!(BU`02(/`"$B)
M$$B%TG7PZ[9F#Q]$``!(C70D!$B-/?\6``#H1_3__TB%P'0Z2&-4)`1(BP66
M=@``2(T$T$B+4`A(B1!(A=)TSF8/'T0``$B+4!!(@\`(2(D02(72=?#KMF8/
M'T0``$B-="0$2(T]OQ8``.CW\___2(7`=#I(8U0D!$B+!49V``!(C0302(M0
M"$B)$$B%TG3.9@\?1```2(M0$$B#P`A(B1!(A=)U\.NV9@\?1```2(UT)`1(
MC3TD%@``Z*?S__](A<!T.DAC5"0$2(L%]G4``$B-!-!(BU`(2(D02(72=,YF
M#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(C70D!$B-/2L6``#H5_/_
M_TB%P'0Z2&-4)`1(BP6F=0``2(T$T$B+4`A(B1!(A=)TSF8/'T0``$B+4!!(
M@\`(2(D02(72=?#KMF8/'T0``$B-="0$2(T]Y14``.@'\___2(7`=#I(8U0D
M!$B+!59U``!(C0302(M0"$B)$$B%TG3.9@\?1```2(M0$$B#P`A(B1!(A=)U
M\.NV9@\?1```2(UT)`1(C3V?%0``Z+?R__](A<!T.DAC5"0$2(L%!G4``$B-
M!-!(BU`(2(D02(72=,YF#Q]$``!(BU`02(/`"$B)$$B%TG7PZ[9F#Q]$``!(
MC70D!$B-/>T4``#H9_+__TB%P'0Z2&-4)`1(BP6V=```2(T$T$B+4`A(B1!(
MA=)TSF8/'T0``$B+4!!(@\`(2(D02(72=?#KMF8/'T0``$B-="0$2(T]"14`
M`.@7\O__2(7`=`](B<9(C3WA%```Z-/R__](C70D!$B-/?44``#H\O'__TB%
MP'0/2(G&2(T]\Q0``.BN\O__2(UT)`1(C3WM%```Z,WQ__](A<!T-TB)QDB-
M/384``#HB?+__TB+1"0(9$@K!"4H````=3](@\002(TUVA0``$B-/4H4``!;
MZ6'R__](C70D!$B-/;`4``#H@/'__TB%P'3"2(G&2(T]0!0``.@\\O__Z['H
M]=7__P\?1```2(/L&$B-/204``!D2(LT)2@```!(B70D"$B-="0$Z#WQ__](
MA<!T,`^V$(#Z,`^4P(32#Y3""="#\`$/ML!(BU0D"&1(*Q0E*````'4.2(/$
M&,,/'T0``#'`Z^+HC]7__V9F+@\?A```````#Q]``%!82('LV````$B)="0H
M2(E4)#!(B4PD.$R)1"1`3(E,)$B$P'0W#RE$)%`/*4PD8`\I5"1P#RF<)(``
M```/*:0DD`````\IK"2@````#RFT)+`````/*;PDP````&1(BP0E*````$B)
M1"08,<!(B?I(C80DX````$B)X4B+/>YR``!(B40D"+X"````2(U$)"#'!"0(
M````QT0D!#````!(B40D$.@&U/__O_\```#HW-+__V9F+@\?A```````D$%4
M55-,C9PD``#__TB![``0``!(@PPD`$PYW'7O2(/L$+H"````,?9D3(LD)2@`
M``!,B:0D"``!`$&)_.COU/__2(UH_TB)ZDC!^C](P>HP2(U$%0`/M\!(*=!(
M*<4/B,````!F9BX/'X0``````)`QTDB)[D2)Y^BSU/__2(/X_P^$M````+H(
M``$`2(GF1(GGZ%G2__^#^/\/A(T```!(F$B#^`=V:$B-1`3X2#G@<EY(C16G
M<0``ZQYF9BX/'X0``````&8N#Q^$``````!(@^@!2#G@<C=(BPA(.0IU[T@I
MX$@!Z$B+E"0(``$`9$@K%"4H````=4](@<00``$`6UU!7,-F+@\?A```````
M2('M```!`$B!_0``__\/A4S___](Q\#_____Z[I(C3U'$@``,<#H!?[__TB-
M/2P2```QP.CW_?__Z'+3__]FD$B#[`CHI]/__XG'Z##2__](A<!T`TB+`$B#
MQ`C##Q\`05932(/L*&1(BQPE*````$B)7"082(G[2(UT)!1(C3WS$0``Z)?N
M__](A<!T!8`X`'4M2(M$)!AD2"L$)2@````/A9D```!(B=Y(@\0H2(T]PA$`
M`%M!7NDS[___#Q\`2(G?2(D$).CDT?__2(L4)$F)QDB)UTB)5"0(Z-#1__])
MC70&`DB)]TB)-"3H#]'__TB#[`A)B=A,C0VO$```2(M4)!!(B<>^`@```$B-
M#:$1``!22(M4)!!(B40D$#'`Z!O3__]86DB+1"089$@K!"4H````=0E(BS0D
MZ6K____H:]+__V9F+@\?A```````05=(C04]$```059F2`]NR$B-!2P1``!!
M569(#V[02(T%)A$``$%49D@/;MA(C04A$0``569(#V[@4TB![$@!``#S#WX%
M5VL``&1,BSPE*````$R)O"0X`0``28G_2(UL)"1(C3W?#P``2,=$)&``````
M2,=$)$``````9@]LP4B)[@\I1"10\P]^!1EK``!(QX0DF`````````!F#VS"
M#Q%$)'CS#WX%!&L``&8/;,,/$80DB````/,/?@7X:@``9@]LQ`\I1"0PZ`+M
M__](A<!T"8`X``^%A`0``.B_T?__B<?H2-#__TB%P`^$_P,``$R+,$V%]@^$
M\P,``$R)]^A;T/__2(U<``%(B=])B=WHF\___T4/M@9(B40D"$F)Q$6$P'1;
M9BX/'X0``````$B)VD4/ML!,B><QP$B-#1H0``"^`@```$F#Q@'HG]'__TDY
MW4B)VD4/M@9)#T/52(G02"G82(/``D@YT$@/0L)(*=-)@\0"2(U<`_Y%A,!U
MKTB-7"1X2(T]4P\``.L-D$B+.TB#PPA(A?]T-$B)[N@L[/__28G%2(7`=.2`
M.`!TWTB)Q^A'[___A<!TTTR)[^A[T/__2(G#2(7`=44/'P!,C6PD4.L-9@\?
MA```````28/%"$F+70!(A=MT)8`[``^$Z@(``$B)W^@"[___A<!TWDB)W^@V
MT/__2(G#2(7`=,Y(B=_H1L___TR+9"0(28G%3(GGZ#;/__]%C:P%!`0``$UC
M[4R)[^ASSO__051)B=A,B>I)B<9(C04<#P``O@(```!03(T-!`X``$R)]S'`
M2(T-^@X``.B#T/__3(GWOL`!``#H]M#__U]!6(/X_W42Z*G/__]$BPA!@_D1
M#X6C`@``2(V$)*````!,B?=(B<9(B40D$.CDS___B<.%P'1>28L/2(L]E&T`
M`$V)\#'`2(T56`\``+X"````Z([-__]%,>1F9BX/'X0``````$B+A"0X`0``
M9$@K!"4H````#X7_`P``2('$2`$``$R)X%M=05Q!74%>05_##Q]``(N$)+@`
M```E`/```#T`0```=8]$BZ0DO````.APS___03G$#X5Y____BX0DN````"7_
M`0``/<`!```/A6+___],B>_H6,W__TB)[DB-/=`-``!)B<3H9NK__TB%P`^$
M70(``$F+/TB)QN@"\?__2(E$)`A(A<`/A$0"``!(BWPD".C*S?__2(G"@_@#
M?E)(BTPD"$B82(E4)!A(C36_#0``2(U\`?SHM<[__X7`=3%(BU0D&(/Z!`^$
MYP(``(U"^TB+3"0(2)B`/`$O#X33`@``9F8N#Q^$```````/'T``2(GN2(T]
MI0P``.C1Z?__2(7`#X38`0``#[8`A,`/A,T!```\,`^$Q0$``$B-->H,``!(
MC3UV#```Z'+J__](C2U_#0``Z.;,__]53(GJ3(T-&PP``%!-B?!(C0U$#0``
MO@(```!,B><QP.B1SO__6%KK10\?1```Z,/-__^#.!%U2.BIS/__@\,!2(/L
M"$V)\%5,C0W7"P``3(GJO@(```!32(T-"0T``$R)YU`QP.A,SO__2(/$(+[`
M`0``3(GGZ+O.__^#^/]TKDR)]^B.S/__3(GF2(T]?`L``.C/Z?__3(GGZ#?Z
M___I`O[__V:0,=OI*_W__V8/'X0``````$B-7"0PZPUF#Q^$``````!(@\,(
M2(L[2(7_#X2/````2(GNZ+CH__](A<!TXX`X`'3>2(G'Z!;-__])B<9(A<!T
MSNG&^___28L/2(L]#VL``$V)\#'`2(T5DPP``+X"````Z`G+___I=OW__P\?
M0`!(B<=(B40D".BC^?__2(N4)#@!``!D2"L4)2@````/A7(!``!(BWPD"$B!
MQ$@!``!;74%<05U!7D%?Z:',__^_#0```$&]#0```+L-````Z/S*__],C35\
M"P``0;A3````2(E$)`A)B<3I8OO__V:028L'2(E$)`CIK_W__P\?`$B+?"0(
M,?8QP.CRR___B<6%P`^$(_[__XG'Z*'W__])B<=(A<`/B!#^__\QTDB-</:)
M[^BXS/__2(UT)"JZ!@```(GOZ&?*__](@_@&#X7(````@7PD*@!#04,/A=K]
M__]F@7PD+DA%#X7-_?__,=))C7?.B>_H=<S__TB+7"00NB@```")[TB)WN@A
MRO__2(/X*`^%@@```$B-!30+``"^`@```$V)\$R)ZL:$),@`````2(T-ZPH`
M`$R-#;\)``!,B>=0,<!3Z$/,__]97ND&_O__38M_"$V%_P^$+_W__TR)_^B7
MRO__2(/X`P^&'?W__TF-?`?\2(TUE@H``.B,R___A<!,#T5\)`A,B7PD".GZ
M_/__Z&7+__](C3UX"@``,<#HU_7__P\?@`````!!5$B-/6H)``!54TB#[!!D
M2(L<)2@```!(B5PD"$B+'9QH``!(C70D!&1(BRL/MH6P````B(6Q````Z('F
M__](A<!T"8`X,0^$8P$``.BN\/__9$B+*TB)[[D#````N@$```!(C34Y"@``
MZ%')__](B<5(A<!T*$B+0!!D2(L[2(T5'PH``$B+,.ABR?__2(M%$$B+,/9&
M#D`/A3D!``!D2(L[N0,```"Z`0```$B--?8)``#H!\G__TB)Q4B%P'0P2(T]
M>0@``$B-="0$Z.[E__](BU402(LZ2(7`#X3>````2(G^9$B+.TB)PNC_R/__
M9$B+.[H!````2(TUJPD``.@:R/__9$B+.TB-%;`)``!(B<;HU\C__V1(BP-(
MC70D!$B-/0\(``#&@+$`````Z(OE__](B04D:```2(G#2(7`=#R^P`$``$B)
MW^@/R___C5`!@_H!=@F#^!$/A80```!(BT0D"&1(*P0E*`````^%C0```$B#
MQ!!;74%<PY!(BSWA9P``Z&3W__](B07-9P``2(G#2(7`=:E(C3W&"0``,<#H
M]\G__P\?@`````"`>`$`#X2<_O__Z8[^__^02(L%H6<``$B+,.@1Y/__Z1W_
M__\/'T``9$B+.^A?R?__Z;G^__^)P4B+!7EG``!(B=I(C3V7"0``2(LP,<#H
MG<G__^A(R?__#Q^$``````!32(/L(&1(BQPE*````$B)7"082(G[2(UT)!1(
MC3U=!P``Z(GD__](A<!T'`^V$(32#Y3`@/HP#Y3""-!U"DB%VW0%@#L`=1A(
MBT0D&&1(*P0E*````'5I2(/$(%O#9I!(B=_H..W__[XO````2(G'2(E$)`CH
M-LC__TB%P$B->`%(#T1\)`CHE,C__[H$````2(TULP<``$B)Q^C@QO__A<!U
MI$B+1"089$@K!"4H````=0U(@\0@2(G?6^FOY___Z'K(__]F+@\?A```````
M2(/L"+^`````Z++&__]F#V\%:D8``$C'0#``````#Q$`9@]O!6=&``#'0'@`
M````#Q%`$&8/;P5D1@``#Q%`($B#Q`C#9F8N#Q^$``````!!5TACPDF)_T%6
M055)B?5!5$F)Q%532(/L&$B+=RA(BU<PC0S&2#GQ2(E/*$B#T@!(P>@=2`'0
M2(E',$AC1WB%P`^%&0$``$&#_#]^=T2)Y4R)Z\'M!HU%_TC!Y0:)1"0$3`'M
M2(E$)`@/'X``````\P]O`TR)_TB#PT!!#Q%'./,/;T/000\11TCS#V]#X$$/
M$4=8\P]O0_!!#Q%':.BMR___2#GK=<B+1"0$]]C!X`9%C60$P$B+1"0(2,'@
M!DV-;`5`26/$2(/X"')K28M5`$F-=T!)C4\X2(/F^$F)5SA)BU0%^$@I\4DI
MS4F)5`<P2`'(2(/@^$B#^`AR(DB#X/@QTDF+3!4`2(D,%DB#P@A(.<)R[F8N
M#Q^$``````!%B6=X2(/$&%M=05Q!74%>05_##Q]$``"H!'5G2(7`=-]!#[95
M`$&(5SBH`G3200^W5`7^9D&)5`<VZ\0/'T``O4````!(C7P'.$R)[BG%1#GE
M00]/[$ACW4B)VNB/Q___08M'>`'H08E'>(/X0'643(G_02GL20'=Z++*___I
MI/[__T&+50!!B5<X08M4!?Q!B50'-.EF____9@\?1```54B)]5-(B?M(@^P8
M3(M&*$B+=C!,B<!(P>@#@^`_C5`!QD0%.(!(8\)(C4P%.(/Z.`^.D0$``+A`
M````*=!T#S'2B=>#P@'&!#D`.<)R\TB)[TB)="0(3(D$).@PRO__9@_OP$R+
M!"1(QT5H`````$B+="0(#Q%%.`\114@/$4582(GR00^VP$V)PDV)P4C!ZAA(
MP>`(2(GQ2<'J$$F)TTR)PDG!Z1@/MOY(B?)(P>D02`GX00^V^@^VR4C!X`A(
M"?A!#[;Y2,'@"$@)^$`/MOX/MO9!#[;32,'@"$@)^$B)[TC!X`A("?!(P>`(
M2`G(2,'@"$@)T$B)17#HD,G__TB+10!(B>](P>@8B`-(BT4`2,'H$(A#`4B+
M10"(8P)(BT4`B$,#2(M%"$C!Z!B(0P1(BT4(2,'H$(A#!4B+10B(8P9(BT4(
MB$,'2(M%$$C!Z!B(0PA(BT402,'H$(A#"4B+11"(8PI(BT40B$,+2(M%&$C!
MZ!B(0PQ(BT482,'H$(A##4B+11B(8PY(BT48B$,/2(M%($C!Z!B(0Q!(BT4@
M2,'H$(A#$4B+12"(8Q)(BT4@B$,32(/$&%M=Z8_#__\/'X``````N#@````I
MT(/X"',LJ`1U>(7`#X2A_O__Q@$`J`(/A);^__\QTF:)5`'^Z8K^__]F#Q^$
M``````")PDC'`0````!(QT01^`````!(C5$(2(/B^$@IT0'(@^#X@_@(#X)6
M_O__@^#X,<F)SX/!"$C'!#H`````.<%R[^D[_O__9BX/'X0``````,<!````
M`,=$`?P`````Z1[^__]F+@\?A```````#Q\`D)"0D)"0D)"0D)"0D)#S#Q[Z
MD)!(BPUM80``Z?#!___S#Q[Z2(/L"$B#Q`C#````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````0`"`"]P<F]C+W-E;&8O97AE`"5S+R5S`$1Y;F%,;V%D97(Z.F)O
M;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``O<')O8R\E:2\E
M<P`N`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`4$523#5,24(`4$523$Q)
M0@!015),-4]05`!015),24\`4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$
M`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%`%!!4E]'3$]"04Q?1$5"
M54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@!005)?1TQ/0D%,7U1%
M35``4$%27T=,3T)!3%]#3$5!3@`Q`&QS965K(&9A:6QE9`!R96%D(&9A:6QE
M9`!,1%],24)205)97U!!5$@`4UE35$5-`"]T;7``5$5-4$1)4@!435``55-%
M4@!54T523D%-10`E,#)X`"5S)7,E<R5S`'!A<BT`<&%R;``N<&%R`'-H;W)T
M(')E860`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE
M=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#8T`"UE
M`"TM`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!F86EL960@*&5R<FYO/25I*0H````````E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*````````56YA8FQE('1O(&-R96%T92!C86-H
M92!D:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A
M8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`````````
M`&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII
M9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?
M7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D
M8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2
M+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*
M)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S
M7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*
M;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE
M(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@
M)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@
M;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@
M)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H
M*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?
M34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D
M8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R
M;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%
M3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@
M1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I
M<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H
M<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN
M9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL
M("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M
M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ
M5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I5
M3DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64[
M"G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@
M73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M
M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*
M9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P
M,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL
M(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG
M<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@
M/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G
M.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y
M9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^
M("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE
M*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?
M<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM0
M05)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S
M96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@
M>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO
M=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C
M(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA
M<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?
M1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD
M(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE
M(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P
M;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A
M9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B
M7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C
M:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H
M92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S
M("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,
M15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I
M.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T
M(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@
M+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?
M1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B
M"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*
M<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA
M;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B
M+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX
M?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@
M*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@
M*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI
M)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B
M=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M
M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L
M;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@
M7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF
M+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M
M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U
M<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE
M?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII
M9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W
M*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#
M86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD
M9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T
M=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I
M;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@
M/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N
M("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD
M(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E
M<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA
M;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA
M;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H
M)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII
M9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA
M;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^
M("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI
M<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*
M;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I
M;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]
M("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II
M<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@
M*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@
M)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P
M87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N
M7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=
M(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%
M55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E
M:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=6
M6S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF
M("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@
M*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G
M02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G
M3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L
M92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G
M86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS
M:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE
M('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D
M,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD[
M"FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG
M4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[
M(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I
M<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`
M24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)
M3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T
M.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@
M*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O
M<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE
M<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W
M.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII
M9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY
M;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>
M7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I]
M.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D
M<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=
M.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I
M<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#
M.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/
M.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ
M1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI
M(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H
M+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H
M9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D
M;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D
M;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O
M=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R
M96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,
M;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI
M8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!8
M6%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY
M("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D[
M"FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS
M92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<
M421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q
M*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD
M?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE
M+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D
M,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0[
M"GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D
M=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I
M;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C
M:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65]
M(#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C
M;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N
M9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A
M;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S
M92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT
M+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@
M86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D
M;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H
M)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z
M.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE
M;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R
M:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7
M<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R
M:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO
M<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]
M"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB
M*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C
M='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T
M>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@
M/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A
M8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X]
M(")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@
M)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L
M;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B
M.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S
M<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER
M92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U
M:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F
M:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@
M("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F
M:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH
M*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@
M7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A
M9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H
M:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H
M-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ
M3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@
M>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO
M=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@
M*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T
M;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O
M;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E
M>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M
M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H
M+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E
M9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I
M;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L
M<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D
M97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H
M)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@
M<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE
M(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"([
M"GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2![
M"F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP
M87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O
M9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*
M)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`
M05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E
M<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D
M97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN
M*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H
M)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E
M<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q
M=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R
M:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@
M0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q
M=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I
M<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3
M<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER
M92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R
M97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E
M<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@
M871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U
M:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE
M=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![
M(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E
M<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@
M>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP
M9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U
M<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER
M.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@
M;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM
M>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS
M965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N
M9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L
M96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E
M96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG
M=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H
M+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C
M86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@
M*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[
M4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C
M86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-
M4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6
M>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U
M8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`
M7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H
M+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B
M.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H
M<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L
M("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE
M+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D
M9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D
M14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O
M*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*
M:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[
M4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA
M;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II
M9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S
M>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R
M;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA
M;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T
M=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?
M<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!
M4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S
M+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES
M>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N
M86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@
M+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?
M<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!
M345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@
M>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@
M)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I
M"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H
M*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<
M+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E
M;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E
M='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF
M;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!
M344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D
M14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"
M04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[
M4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*
M:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP
M<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I
M9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF
M:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP
M('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP
M86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2
M.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A
M<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@
M<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE
M.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/
M4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2
M(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@
M)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``$-!0TA%``!P97)L>'-I+F,`````
M`````2-%9P````")J\WO`````/[<NI@`````=E0R$`````#PX=+#````````
M`````````1L#._P````>````<'___S`!``#@@O__6`$``/""__\`!@```(7_
M_Q@!``#PA?__<`$``%"<___``0``,)W___@!````GO__1`(``&"@__^(`@``
M\*#__ZP"``!PHO__X`(``,"B___\`@``\*+__Q`#``#0H___1`,``."C__]8
M`P```*;__[P#```@IO__V`,``'"G__\`!```T*O__R0$``!`K/__0`0```"M
M__]<!```4*[__YP$``!PKO__M`0``&"O___L!```<+;__YP%``"`N/__T`4`
M`%"Y__\L!@``H+G__T0&``!@N___D`8``-Z]___`!@```````!0`````````
M`7I2``%X$`$;#`<(D`$``!0````<````X(/__R8`````1`<0`````"0````T
M````.'[__W`#````#A!&#AA*#PMW"(``/QH[*C,D(@`````4````7````("!
M__\(``````````````!,````=````'B$__]:%@```$(.$(\"1@X8C@-"#B"-
M!$(.*(P%00XPA@9!#CB#!T<.T`4#-18*#CA!#C!!#BA"#B!"#AA"#A!"#@A!
M"P```#0```#$````B)K__^``````0@X0C`)!#AB&`T$.((,$1PZ@($D.P"`"
M=0H.($$.&$$.$$(."$$+2````/P````PF___Q0````!"#A"/`D(.&(X#0@X@
MC01"#BB,!4$.,(8&00XX@P=$#D`";`H..$0.,$$.*$(.($(.&$(.$$(."$D+
M`$````!(`0``M)O__UD"````0@X0C@)$#AB-`T(.((P$00XHA@5!#C"#!D0.
M4`,K`0H.,$$.*$$.($(.&$(.$$(."$<+(````(P!``#0G?__@P````!!#A"#
M`D<.L`$"=`H.$$$."$$+,````+`!```\GO__=`$```!"#A".`D$.&(8#00X@
M@P1'#M`!?@H.($$.&$$.$$(."$,+`!@```#D`0``B)___TL`````00X0@P)M
M#@@````0``````(``+R?__\E`````````#`````4`@``V)___]T`````00X0
MA@)!#AB#`T<.F"!,#IA`20[00`*T"@X81`X000X(00L0````2`(``(2@__\%
M`````````&````!<`@``@*#__QH"````0@X0CP)"#AB.`T(.((T$0@XHC`5!
M#C"&!D$..(,'1PZX($P.\"$";0H..$$.,$$.*$(.($(.&$(.$$(."$0+`OP.
M^"%.#H`B90[X(4$.\"$````8````P`(``#RB__\?`````$$.$(,"60X(````
M)````-P"``!`HO__00$```!'#H@@20ZP(`+T"@X(1`MA"@X(1PL``"`````$
M`P``:*/__UL$````00X0@P)$#B`#%@0*#A!/#@A%"Q@````H`P``I*?__V$`
M````1`X@`DX*#@A&"P`8````1`,``/BG__^T`````$$.$$$."$<.X`$`/```
M`&`#``"<J/__3@$```!"#A",`D$.&(8#00X@@P1(#`N@@`11#0=$#K"`!`+@
M"@X@00X800X00@X(2PL``!0```"@`P``K*G__QT`````1`X06`X(`#0```"X
M`P``M*G__^4`````0@X0C@)!#AB#`T0.0`)'"@X82`X00@X(2`MU#DA?#E!2
M#DA!#D``K````/`#``!LJO__"0<```!"#A"/`DD.&(X#3@X@C01.#BB,!4T.
M,(8&1@XX@P='#H`#`_X!#H@#5@Z0`V8.B`-"#H`#`H$*#CA$#C!!#BA"#B!"
M#AA"#A!"#@A%"P,K`0Z(`TL.D`-:#H@#00Z``UT.B`-$#I`#4`Z8`TL.H`-+
M#H`#`N@*#CA!#C!!#BA"#B!"#AA"#A!"#@A%"P,&`0Z(`T,.D`-&#H@#00Z`
M`P`P````H`0``,RP__\(`@```$(.$(P"2`X8A@-!#B"#!$0.,`-K`0H.($$.
M&$$.$$(."$(++````-0$``"HLO__Q@````!!#A"#`D0.,`)7"@X000X(0PL"
M6`H.$$0."$4+````*`````0%``#H?/__"P(```!!#A"&`D$.&(,#1`Y0`VH!
M"@X80PX000X(00L4````,`4``!RS__]%`````$0.$`)`#@A(````2`4``%2S
M__^Z`0```$(.$(\"2`X8C@-"#B"-!$4.*(P%1`XPA@9!#CB#!T0.4`,.`0H.
M.$$.,$$.*$(.($(.&$(.$$(."$8++````)0%``#(M/__8P(```!!#A"&`D0.
M&(,#1PXP`ZX!"@X800X000X(3`L`````$````,0%```6M___$@``````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````)`F````````4"8```````!.80```````.E@````
M````!F$```````!?80````````$`````````Z`(````````!`````````/,"
M````````'0````````!\!`````````P``````````"`````````-````````
M`*!>````````&0````````"@NP```````!L`````````"``````````:````
M`````*B[````````'``````````(``````````0`````````P`,```````#U
M_O]O`````%`&````````!0`````````0$`````````8`````````0`<`````
M```*`````````+$$````````"P`````````8`````````!4`````````````
M```````#`````````/"]`````````@`````````0!0```````!0`````````
M!P`````````7`````````.`7````````!P``````````%@````````@`````
M````X`$````````)`````````!@`````````'@`````````(`````````/O_
M_V\``````0``"`````#^__]O`````(`5````````____;P`````!````````
M`/#__V\`````PA0```````#Y__]O``````@`````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#0NP``````````````````````````
M```V(````````$8@````````5B````````!F(````````'8@````````AB``
M``````"6(````````*8@````````MB````````#&(````````-8@````````
MYB````````#V(`````````8A````````%B$````````F(0```````#8A````
M````1B$```````!6(0```````&8A````````=B$```````"&(0```````)8A
M````````IB$```````"V(0```````,8A````````UB$```````#F(0``````
M`/8A````````!B(````````6(@```````"8B````````-B(```````!&(@``
M`````%8B````````9B(```````!V(@```````(8B````````EB(```````"F
M(@```````+8B````````QB(```````#6(@```````.8B````````]B(`````
M```&(P```````!8C````````)B,````````V(P```````$8C````````5B,`
M``````!F(P```````'8C````````AB,`````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````C`````````"E!!4BYP;0H``````````/AB
M````````1T-#.B`H4U5312!,:6YU>"D@,34N,2XQ(#(P,C4P-C(V```N<VAS
M=')T86(`+FEN=&5R<``N;F]T92YG;G4N<')O<&5R='D`+FYO=&4N04))+71A
M9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T
M<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;&$N9'EN`"YR96QA
M+G!L=``N:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F
M<F%M95]H9'(`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD
M871A+G)E;"YR;P`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````````
M````````````````````````````````````````````````````````````
M```````````````````+`````0````(`````````&`,````````8`P``````
M`!P````````````````````!````````````````````$P````<````"````
M`````#@#````````.`,```````!`````````````````````"```````````
M`````````"8````'`````@````````!X`P```````'@#````````(```````
M``````````````0````````````````````T````!P````(`````````F`,`
M``````"8`P```````"0````````````````````$````````````````````
M2P````4````"`````````,`#````````P`,```````",`@````````<`````
M````"``````````$`````````$<```#V__]O`@````````!0!@```````%`&
M````````\``````````'``````````@```````````````````!1````"P``
M``(`````````0`<```````!`!P```````-`(````````"`````$````(````
M`````!@`````````60````,````"`````````!`0````````$!````````"Q
M!````````````````````0```````````````````&$```#___]O`@``````
M``#"%````````,(4````````O``````````'``````````(``````````@``
M``````!N````_O__;P(`````````@!4```````"`%0```````(``````````
M"`````$````(````````````````````?0````0````"```````````6````
M`````!8```````#@`0````````<`````````"``````````8`````````(<`
M```$````0@````````#@%P```````.`7````````$`4````````'````&0``
M``@`````````&`````````"1`````0````8``````````"``````````(```
M`````!L````````````````````$````````````````````C`````$````&
M`````````"`@````````("````````!P`P``````````````````$```````
M```0`````````)<````!````!@````````"0(P```````)`C````````"```
M``````````````````@`````````"`````````"@`````0````8`````````
MH",```````"@(P`````````[```````````````````@````````````````
M````I@````$````&`````````*!>````````H%X````````-````````````
M````````!````````````````````*P````!`````@``````````8```````
M``!@````````L$```````````````````!````````````````````"T````
M`0````(`````````L*````````"PH````````/P````````````````````$
M````````````````````P@````$````"`````````+"A````````L*$`````
M``#8!0``````````````````"````````````````````,P````.`````P``
M``````"@NP```````*"K````````"`````````````````````@`````````
M"`````````#8````#P````,`````````J+L```````"HJP````````@`````
M```````````````(``````````@`````````Y`````$````#`````````+"[
M````````L*L````````@````````````````````"```````````````````
M`/$````&`````P````````#0NP```````-"K````````(`(````````(````
M``````@`````````$`````````";`````0````,`````````\+T```````#P
MK0```````!`"```````````````````(``````````@`````````^@````$`
M```#``````````#``````````+`````````H````````````````````"```
M```````````````````!```(`````P````````!`P````````"BP````````
M6````````````````````"`````````````````````%`0```0```#``````
M```````````````HL````````"(````````````````````!``````````$`
M`````````0````,`````````````````````````2K`````````.`0``````
9`````````````0``````````````````````
